@@ -6,11 +6,11 @@ Interchange6 - Open Source Shop Machine
 
 =head1 VERSION
 
-0.102
+0.103
 
 =cut
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 =head1 DESCRIPTION
 
@@ -51,6 +51,10 @@ and price caching.
 
 Please anticipate API changes in this early state of development.
 
+=head1 ACKNOWLEDGEMENTS
+
+Hunter McMillen, GH #31, #33.
+
 =head1 AUTHORS
 
 Stefan Hornburg (Racke), C<racke@linuxia.de>
@@ -59,7 +63,7 @@ Peter Mottram C<peter@sysnix.com>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2015 Stefan Hornburg (Racke).
+Copyright 2011-2016 Stefan Hornburg (Racke).
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
