@@ -14,14 +14,13 @@ use DateTime;
 use Interchange6::Cart::Product;
 use Scalar::Util 'blessed';
 use Try::Tiny;
-use Moo;
-use MooseX::CoverableModifiers;
-use MooX::HandlesVia;
-use Types::Standard qw/ArrayRef InstanceOf Str/;
 use Types::Common::String qw/NonEmptyStr/;
+use Types::Standard qw/ArrayRef InstanceOf Str/;
 
+use Moo;
+use MooX::HandlesVia;
+use MooseX::CoverableModifiers;
 with 'Interchange6::Role::Costs';
-
 use namespace::clean;
 
 =head1 DESCRIPTION
@@ -151,8 +150,9 @@ sub _build_subtotal {
     my $self = shift;
 
     my $subtotal = 0;
-
-    map { $subtotal += $_->total } $self->products_array;
+    foreach my $product ( $self->products_array ) {
+       $subtotal += $product->total;
+    }
 
     return sprintf( "%.2f", $subtotal );
 }
@@ -202,12 +202,13 @@ has weight => (
 
 sub _build_weight {
     my $self = shift;
-    my $weight;
+   
+    my $weight = 0;
+    foreach my $product ( grep { defined $_->weight } $self->products_array ) {
+       $weight += $product->weight * $product->quantity;
+    }
 
-    map { $weight += $_->weight * $_->quantity }
-      grep { defined $_->weight } $self->products_array;
-
-    return $weight ? $weight : 0;
+    return $weight;
 }
 
 =head1 METHODS
@@ -376,9 +377,11 @@ which is commonly used as number of products. If you have 5 apples and 6 pears i
 
 sub quantity {
     my $self = shift;
-    my $qty  = 0;
 
-    map { $qty += $_->quantity } $self->products_array;
+    my $qty  = 0;
+    foreach my $product ( $self->products_array ) {
+       $qty += $product->quantity;
+    }
 
     return $qty;
 }
@@ -503,7 +506,7 @@ sub update {
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2015 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2011-2016 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
