@@ -3,14 +3,14 @@
 package Interchange6::Cart::Product;
 
 use strict;
-use Moo;
-use MooseX::CoverableModifiers;
-use MooX::HandlesVia;
-use Types::Standard qw/Defined HashRef InstanceOf Int Num Str Undef/;
 use Types::Common::Numeric qw/PositiveInt PositiveOrZeroNum/;
 use Types::Common::String qw/NonEmptyStr/;
-with 'Interchange6::Role::Costs';
+use Types::Standard qw/Defined HashRef HasMethods InstanceOf Int Maybe Num Str Undef/;
 
+use Moo;
+use MooX::HandlesVia;
+use MooseX::CoverableModifiers;
+with 'Interchange6::Role::Costs';
 use namespace::clean;
 
 =head1 NAME 
@@ -54,9 +54,10 @@ A reference to the Cart object that this Cart::Product belongs to.
 
 has cart => (
     is      => 'ro',
-    isa     =>  Undef | InstanceOf ['Interchange6::Cart'],
+    isa     =>  Maybe[InstanceOf ['Interchange6::Cart']],
     default => undef,
     writer  => 'set_cart',
+    weak_ref => 1,
 );
 
 =head2 name
@@ -67,7 +68,7 @@ Product name is required.
 
 has name => (
     is       => 'ro',
-    isa      => Defined & NonEmptyStr,
+    isa      => NonEmptyStr,
     required => 1,
 );
 
